import { EChartsType, EChartsOption, EChartsInitOpts } from "echarts-comp/core";
import React, { CSSProperties } from "react";
export declare const ECharts: React.NamedExoticComponent<EChartsProps>;
/** When the theme or initOption changes (shallow comparison), reinitialize Echarts */
export declare function useECharts(config?: UseEchartsOption): React.RefObject<HTMLDivElement>;
export type { EChartsType, EChartsOption, EChartsInitOpts } from "echarts-comp/core";
export interface UseEchartsOption {
    /** echarts 主题，变更会导致 echarts 变化 */
    theme?: string | object;
    /** echarts 初始化配置，变更会导致 echarts 变化 */
    init?: EChartsInitOpts;
    option?: EChartsOption;
    loading?: boolean;
    /** 固定渲染大小;  默认会自动监听 window resize 事件, 自动调用 Echarts.resize(); 设置为true将不会监听 */
    fixedSize?: boolean;
    /**
     * Echarts 实例发生变化时触发
     * @param oldInstance - 如果不存在，说明是第一次初始化
     */
    onChange?: (echarts: EChartsType, oldInstance?: EChartsType) => void;
}
export type EChartsProps = UseEchartsOption & {
    style?: CSSProperties;
};
