import { init } from 'echarts-comp/core';
import React, { memo, useRef, useLayoutEffect, useCallback } from 'react';

const ECharts = memo(function ECharts(props) {
    const domRef = useECharts(props);
    return React.createElement("div", { style: props.style, ref: domRef });
});
/** When the theme or initOption changes (shallow comparison), reinitialize Echarts */
function useECharts(config = {}) {
    const { fixedSize, loading, onChange, option, init: init$1, theme } = config;
    const domRef = useRef(null);
    const chartRef = useRef();
    const needInit = useEchartsNeedInit(init$1);
    const oldOption = useOldValue(config.option);
    useLayoutEffect(() => {
        if (!chartRef.current || objectIsEqual(oldOption, option))
            return;
        updateEchartsOption(chartRef.current, option ?? {});
    });
    useLayoutEffect(refreshLoading, [loading]);
    useLayoutEffect(() => {
        if (!domRef.current) {
            console.error("Unable to get DOM instance");
        }
        const oldInstance = chartRef.current;
        oldInstance?.dispose();
        const instance = init(domRef.current, theme, init$1);
        chartRef.current = instance;
        option && updateEchartsOption(instance, option);
        refreshLoading();
        onChange?.(instance, oldInstance);
        return () => instance.dispose();
    }, [theme, needInit]);
    const onWindowResize = useCallback((ev) => chartRef.current?.resize(), []);
    //resize
    useLayoutEffect(() => {
        if (fixedSize)
            window.removeEventListener("resize", onWindowResize);
        else
            window.addEventListener("resize", onWindowResize);
        return () => window.removeEventListener("resize", onWindowResize);
    }, [fixedSize]);
    function refreshLoading() {
        const chart = chartRef.current;
        if (!chart)
            return;
        if (loading)
            chart.showLoading();
        else
            chart.hideLoading();
    }
    return domRef;
}
function updateEchartsOption(instance, opts) {
    instance.setOption(opts ?? {}, true, false);
}
function useOldValue(value) {
    const ref = useRef();
    const oldValue = ref.current;
    ref.current = value;
    return oldValue;
}
function useEchartsNeedInit(initOpts) {
    const oldOpts = useOldValue(initOpts);
    const changeObj = useRef({});
    if (!objectIsEqual(oldOpts, initOpts)) {
        changeObj.current = {};
    }
    return changeObj.current;
}
function objectIsEqual(obj1, obj2) {
    if (obj1 === obj2)
        return true;
    if (typeof obj1 !== "object" || typeof obj2 !== "object")
        return obj1 === obj2;
    if (obj1 === null)
        return obj1 === obj2;
    const keys1 = Object.keys(obj1);
    const keys2 = Object.keys(obj2);
    if (keys1.length !== keys2.length)
        return false;
    for (let i = 0; i < keys2.length; i++) {
        if (obj1[keys2[i]] !== obj2[keys2[i]])
            return false;
    }
    return true;
}

export { ECharts, useECharts };
